/****************************************************************************
   Copyright (C) 1995, 1996, 1997  Intel Corporation.  All rights reserved.
****************************************************************************/

#ifndef INCLUDED_DINOAV_H
#define INCLUDED_DINOAV_H

#include <dino.h>

#ifdef __cplusplus
extern "C" {
#endif

//
// Win32 DLL conventions for import/export of symbols
//

#ifdef _AVDINO_
#define DINOAV_SYMBOL   DllExport
#else
#define DINOAV_SYMBOL   DllImport
#endif

#define APIFN           DINOAV_SYMBOL WINAPI

//
// AV defines
//

// timebase equates, used in avGetTimebase and avSetTimebase
#define AV_TB_MILLISECONDS  0
#define AV_TB_SAMPLES       1

// play flags, used in avPlay
#define AV_PLAY_REPEAT      0x00000001
#define AV_PLAY_EXCLUSIVE   0x00000002  // turns off double buffering

// preload flags, used in avPreload
#define PL_PERSISTENT       0x00000001
#define PL_DECOMPRESS       0x00000002
#define PL_BACKGROUND       0x00000004
#define PL_ENTIRE_STREAM    0x00000008

// return values from avGetStatus
#define AV_STOPPED          0
#define AV_PLAYING          1
#define AV_PAUSED           2

// Audio sample rates
#define AV_8KHZ             8000
#define AV_11KHZ            11025
#define AV_22KHZ            22050
#define AV_44KHZ            44100

// Audio bits per sample (in a single channel)
#define AV_8BIT             8
#define AV_16BIT            16

// Audio number of channels
#define AV_MONO             1
#define AV_STEREO           2

// Audio panning ranges
#define AV_PAN_MIN          -10000
#define AV_PAN_MAX          10000
#define AV_PAN_DEFAULT      0

// Audio volume ranges
#define AV_VOLUME_MIN       -10000
#define AV_VOLUME_MAX       0
#define AV_VOLUME_DEFAULT   0

//
// AV effect GUIDs
//
// FX_SCALE2X 2EB42220-5267-11cf-95D6-00AA006D7CE1
//

#ifdef _AVDINO_
DINOAV_SYMBOL DEFINE_GUID(FX_SCALE2X,0x2EB42220,0x5267,0x11CF,0x95,0xD6,0x00,0xAA,0x00,0x6D,0x7C,0xE1);
#else
DINOAV_SYMBOL GUID FX_SCALE2X;
#endif

//
// AV enumerations
//

typedef enum 
{
    AV_STATUS_STATE,
    AV_STATUS_CURRENTSAMPLE,
    AV_STATUS_VOLUME,
    AV_STATUS_PAN,
    AV_STATUS_CODECREUSE,
    AV_STATUS_EXCLUSIVEMODE,
    AV_STATUS_SETDECODERECT,
    AV_STATUS_DECODEINIT

} AVSTATUS;

typedef enum
{
    AV_INFO_LENGTH,
    AV_INFO_SAMPLERATE,
    AV_INFO_WIDTH,
    AV_INFO_HEIGHT,
    AV_INFO_NUMCHANNELS,
    AV_INFO_BITSPERSAMPLE,
    AV_INFO_COLORDEPTH,
    AV_INFO_4CC,
    AV_INFO_TRANSPARENCY,
    AV_INFO_WAVEFORMAT

} AVINFO;

typedef enum
{
    AV_DESTROY_AUDIO

} AVDESTROY;

//
// AV types
//

typedef void*   HFIL;
typedef HFIL*   LPHFIL;

typedef void*   HAV;
typedef HAV*    LPHAV;

typedef void*   HTRACK;
typedef HTRACK* LPHTRACK;

typedef void*   HTABLE;
typedef HTABLE* LPHTABLE;

//
// AV function prototypes
//

// General functions

extern DINORVAL APIFN avSetSysDefaultTimer( HTIMER hTimer );

extern DINORVAL APIFN avGetSysAudioFormat( DWORD* pSamplesPerSec,
                                           WORD* pBitsPerSample,
                                           WORD* pChannels,
                                           HWND* phMainWnd );
extern DINORVAL APIFN avSetSysAudioFormat( DWORD nSamplesPerSec,
                                           WORD nBitsPerSample,
                                           WORD nChannels,
                                           HWND hMainWnd );

extern DINORVAL APIFN avDisconnectSysAudio( void );
extern DINORVAL APIFN avReconnectSysAudio( void );

extern DINORVAL APIFN avDestroySys( AVDESTROY what );

// HFIL specific functions

extern DINORVAL APIFN hfilCreate( HFIL* phfil );
extern DINORVAL APIFN hfilDelete( HFIL hfil );

extern DINORVAL APIFN hfilLoad( HFIL hfil,
                                PSTR pszFilename );

extern DINORVAL APIFN hfilFlush( HFIL hfil );
extern DINORVAL APIFN hfilPreload( HFIL hfil,
                                   DWORD dwPreloadFlags,
                                   DWORD dwOffset,
                                   DWORD dwFrames );

// HAV specific functions

extern DINORVAL APIFN avCreate( HAV* phAV );
extern DINORVAL APIFN avDelete( HAV hAV );

extern DINORVAL APIFN avGetData( HAV hAV,
                                 HFIL* phfil );
extern DINORVAL APIFN avSetData( HAV hAV,
                                 HFIL hfil,
                                 HTRACK* phVidTrack,
                                 HTRACK* phAudTrack );

extern DINORVAL APIFN avGetInfo( HAV hAV,
                                 AVINFO infoType,
                                 void* pInfo );

extern DINORVAL APIFN avConnectTimer( HAV hAV,
                                      HTIMER hTimer );
extern DINORVAL APIFN avDisconnectTimer( HAV hAV );

extern DINORVAL APIFN avGetTimebase( HAV hAV,
                                     WORD* timeBase );
extern DINORVAL APIFN avSetTimebase( HAV hAV,
                                     WORD wTimebase );

extern DINORVAL APIFN avFlush( HAV hAV );
extern DINORVAL APIFN avPreload( HAV hAV,
                                 DWORD dwPreloadFlags,
                                 DWORD dwOffset,
                                 DWORD dwFrames );

extern DINORVAL APIFN avAddAudioTrack( HAV hAV,
                                       HFIL hfil,
                                       DWORD streamNum,
                                       HTRACK* phAudTrack );
extern DINORVAL APIFN avRemoveAudioTrack( HAV hAV,
                                          HTRACK hAudTrack );

extern DINORVAL APIFN avAddVideoTrack( HAV hAV,
                                       HFIL hfil,
                                       DWORD streamNum,
                                       HTRACK* phVidTrack );
extern DINORVAL APIFN avRemoveVideoTrack( HAV hAV,
                                          HTRACK hVidTrack );

extern DINORVAL APIFN avGetMasterTrack( HAV hAV,
                                        HTRACK* phTrack );
extern DINORVAL APIFN avSetMasterTrack( HAV hAV,
                                        HTRACK hTrack );

extern DINORVAL APIFN avCreateLoop( HAV hAV,
                                    DWORD dwStart,
                                    DWORD dwEnd,
                                    DWORD dwLoopCount,
                                    DWORD dwImmediateFlag );
extern DINORVAL APIFN avDeleteLoop( HAV hAV,
                                    DWORD dwStart,
                                    DWORD dwEnd );

extern DINORVAL APIFN avPause (HAV hAV);
extern DINORVAL APIFN avPlay( HAV hAV,
                              DWORD dwPlayFlags,
                              DWORD dwFrom,
                              DWORD dwTo );
extern DINORVAL APIFN avResume( HAV hAV );
extern DINORVAL APIFN avSeek( HAV hAV,
                              int Origin,
                              long lPos );
extern DINORVAL APIFN avStop( HAV hAV );

extern DINORVAL APIFN avGetStatus( HAV hAV,
                                   AVSTATUS statusType,
                                   void* statusInfo );
extern DINORVAL APIFN avSetStatus( HAV hAV,
                                   AVSTATUS statusType,
                                   LONG lStatusInfo );

// HTRACK specific functions

extern DINORVAL APIFN audGetInfo( HTRACK hTrack,
                                  AVINFO infoType,
                                  void* pInfo );

extern DINORVAL APIFN audGetStatus( HTRACK hAudTrack,
                                    AVSTATUS statusType,
                                    void* pStatusInfo );
extern DINORVAL APIFN audSetStatus( HTRACK hAudTrack,
                                    AVSTATUS statusType,
                                    LONG lStatusInfo );

extern DINORVAL APIFN vidGetInfo( HTRACK hTrack,
                                  AVINFO infoType,
                                  void* pInfo );

extern DINORVAL APIFN vidGetStatus( HTRACK hVidTrack,
                                    AVSTATUS statusType,
                                    void* pStatusInfo );
extern DINORVAL APIFN vidSetStatus( HTRACK hVidTrack,
                                    AVSTATUS statusType,
                                    long lStatusInfo );

extern DINORVAL APIFN vidGetPalette( HTRACK hVidTrack,
                                     LOGPALETTE* pPal );
extern DINORVAL APIFN vidSetPalette( HTRACK hVidTrack,
                                     LOGPALETTE* pPal );

extern DINORVAL APIFN vidSendCodecMessage( HTRACK hTrack,
                                           DWORD dwMsg,
                                           DWORD dwParam1,
                                           DWORD dwParam2 );

extern DINORVAL APIFN vidGetFileCollisionData( HTRACK hVidTrack,
                                               DWORD dwFrameNum,
                                               DWORD dwSizeBuf,
                                               void* pBuf,
                                               COLLISION_DATA_CONTEXT* pCDC );
extern DINORVAL APIFN vidIgnoreFileCollisionData( HTRACK hVidTrack );
extern DINORVAL APIFN vidUseFileCollisionData( HTRACK hVidTrack );

// HTABLE specific functions

extern DINORVAL APIFN avCreateBranchTable( HTABLE* hTable,
                                           WORD wNumEntries );
extern DINORVAL APIFN avDeleteBranchTable( HTABLE hTable );

extern DINORVAL APIFN avClearBranchTable( HTABLE hTable );

extern DINORVAL APIFN avClearTableEntry( HTABLE hTable,
                                         WORD wEntryNum );
extern DINORVAL APIFN avGetTableEntry( HTABLE hTable,
                                       WORD wEntryNum,
                                       HAV* phAV,
                                       DWORD* dwOffset,
                                       DWORD* dwNumFrames );
extern DINORVAL APIFN avSetTableEntry( HTABLE hTable,
                                       WORD wEntryNum,
                                       HAV hAV,
                                       DWORD dwFrom,
                                       DWORD dwTo );

extern DINORVAL APIFN avChooseTableEntry( HTABLE hTable,
                                          WORD wEntryNum,
                                          BOOL bFlush,
                                          DWORD dwPlayFlags );

#ifdef __cplusplus
}
#endif

#endif


